@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.48.0"
+version = "1.50.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +27,7 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.9-r7",
+apk_tools_min_version = {"edge": "2.12.10-r1",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -51,7 +51,12 @@ ondev_min_version = "0.2.0"
 # Programs that pmbootstrap expects to be available from the host system. Keep
 # in sync with README.md, and try to keep the list as small as possible. The
 # idea is to run almost everything in Alpine chroots.
-required_programs = ["git", "openssl", "ps"]
+required_programs = [
+    "git",
+    "openssl",
+    "ps",
+    "tar",
+]
 sudo = which_sudo()
 
 # Keys saved in the config file (mostly what we ask in 'pmbootstrap init')
@@ -262,7 +267,7 @@ chroot_outdated = 3600 * 24 * 2
 # specify architectures supported by Alpine here. For cross-compiling,
 # we need to generate the "musl-$ARCH", "binutils-$ARCH" and "gcc-$ARCH"
 # packages (use "pmbootstrap aportgen musl-armhf" etc.).
-build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86"]
+build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86", "riscv64"]
 
 # Packages that will be installed in a chroot before it builds packages
 # for the first time
@@ -363,7 +368,7 @@ necessary_kconfig_options_waydroid = {
             "PSI_DEFAULT_DISABLED": False,
         }
     },
-    "<5.18_rc1": {  # option has been dropped
+    "<5.18": {  # option has been dropped
         "all": {
             "ASHMEM": True,
         }
@@ -426,7 +431,7 @@ necessary_kconfig_options_nftables = {
             "IP6_NF_NAT": True,
         }
     },
-    ">=3.13.0 <5.17_rc1": {  # option has been dropped
+    ">=3.13.0 <5.17": {  # option has been dropped
         "all": {  # all arches
             "NFT_COUNTER": True,
         },
@@ -495,14 +500,19 @@ necessary_kconfig_options_containers = {
     ">=3.6": {
         "all": {  # all arches
             "MEMCG": True,
-            "MEMCG_SWAP": True,
             "DM_THIN_PROVISIONING": True,  # Storage Drivers
+            "SWAP": True,
         },
         "x86 x86_64": {  # only for x86, x86_64 (and sparc64, ia64)
             "HUGETLB_PAGE": True,
             "CGROUP_HUGETLB": True,  # Optional section
         }
     },
+    ">=3.6 <6.1": {  # option has been dropped
+        "all": {
+            "MEMCG_SWAP": True,
+        }
+    },
     ">=3.7 <5.0": {
         "all": {
             "NF_NAT_IPV4": True,  # Needed for lxc
@@ -566,6 +576,51 @@ necessary_kconfig_options_netboot = {
     },
 }
 
+# Necessary wireguard & wg-quick kernel config options
+# From https://gitweb.gentoo.org/repo/gentoo.git/tree/net-vpn/wireguard-tools/wireguard-tools-1.0.20210914.ebuild?id=76aaa1eeb6f001baaa68e6946f917ebb091bbd9d # noqa
+necessary_kconfig_options_wireguard = {
+    ">=5.6_rc1": {  # all versions
+        "all": {  # all arches
+            "WIREGUARD": True,
+            "IP_ADVANCED_ROUTER": True,
+            "IP_MULTIPLE_TABLES": True,
+            "IPV6_MULTIPLE_TABLES": True,
+            "NF_TABLES": True,
+            "NF_TABLES_IPV4": True,
+            "NF_TABLES_IPV6": True,
+            "NFT_CT": True,
+            "NFT_FIB": True,
+            "NFT_FIB_IPV4": True,
+            "NFT_FIB_IPV6": True,
+            "NF_CONNTRACK_MARK": True,
+        },
+    },
+}
+
+# Necessary file system config options
+necessary_kconfig_options_filesystems = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "BTRFS_FS": True,
+            "EXFAT_FS": True,
+            "EXT4_FS": True,
+            "F2FS_FS": True,
+        },
+    },
+}
+
+# Various other kernel config options
+necessary_kconfig_options_community = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "INPUT_UINPUT": True,  # buffyboard
+            "LEDS_TRIGGER_TIMER": True,  # hfd-service
+            "NETFILTER_XT_MATCH_TCPMSS": True,  # change MTU, e.g. for Wireguard
+            "NETFILTER_XT_TARGET_TCPMSS": True,  # change MTU, e.g. for Wireguard
+        },
+    },
+}
+
 # Necessary UEFI boot config options
 necessary_kconfig_options_uefi = {
     ">=0.0.0": {  # all versions
@@ -659,9 +714,14 @@ apkbuild_attributes = {
 apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
     "!pmb:kconfig-check",
-    "pmb:kconfigcheck-waydroid",
+    "pmb:kconfigcheck-community",
     "pmb:kconfigcheck-containers",
+    "pmb:kconfigcheck-iwd",
+    "pmb:kconfigcheck-netboot",
     "pmb:kconfigcheck-nftables",
+    "pmb:kconfigcheck-uefi",
+    "pmb:kconfigcheck-waydroid",
+    "pmb:kconfigcheck-zram",
     "pmb:cross-native",
     "pmb:gpu-accel",
     "pmb:strict",
@@ -814,7 +874,7 @@ uuu specific: $UUU_SCRIPT
 """
 flashers = {
     "fastboot": {
-        "depends": ["android-tools", "avbtool"],
+        "depends": [],  # pmaports.cfg: supported_fastboot_depends
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
             "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
@@ -876,7 +936,7 @@ flashers = {
     # Some Samsung devices need a 'boot.img' file, just like the one generated
     # fastboot compatible devices. Example: s7562, n7100
     "heimdall-bootimg": {
-        "depends": ["heimdall", "avbtool"],
+        "depends": [],  # pmaports.cfg: supported_heimdall_depends
         "actions": {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
@@ -999,9 +1059,15 @@ newapkbuild_arguments_switches_other = [
 # Patterns of package names to ignore for automatic pmaport upgrading
 # ("pmbootstrap aportupgrade --all")
 upgrade_ignore = ["device-*", "firmware-*", "linux-*", "postmarketos-*",
-                  "*-aarch64", "*-armhf", "*-armv7"]
+                  "*-aarch64", "*-armhf", "*-armv7", "*-riscv64"]
 
 #
 # SIDELOAD
 #
 sideload_sudo_prompt = "[sudo] password for %u@%h: "
+
+#
+# CI
+#
+# Valid options für 'pmbootstrap ci', see https://postmarketos.org/pmb-ci
+ci_valid_options = ["native", "slow"]
